# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/aggregated_state_price_v1/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2sdk/stream/aggregated_state_price_v1/request.proto\x12\x08kaikosdk\"5\n#StreamAggregatedStatePriceRequestV1\x12\x0e\n\x06\x61ssets\x18\x01 \x03(\tB\xb9\x01\n.com.kaiko.sdk.stream.aggregated_state_price_v1P\x01Z\\github.com/kaikodata/kaiko-go-sdk/stream/aggregated_state_price_v1;aggregated_state_price_v1\xaa\x02&KaikoSdk.Stream.AggregatedStatePriceV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.aggregated_state_price_v1.request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.com.kaiko.sdk.stream.aggregated_state_price_v1P\001Z\\github.com/kaikodata/kaiko-go-sdk/stream/aggregated_state_price_v1;aggregated_state_price_v1\252\002&KaikoSdk.Stream.AggregatedStatePriceV1'
  _globals['_STREAMAGGREGATEDSTATEPRICEREQUESTV1']._serialized_start=64
  _globals['_STREAMAGGREGATEDSTATEPRICEREQUESTV1']._serialized_end=117
# @@protoc_insertion_point(module_scope)
