# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/constant_duration_indices_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.stream.index_v1 import commodity_pb2 as sdk_dot_stream_dot_index__v1_dot_commodity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6sdk/stream/constant_duration_indices_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a#sdk/stream/index_v1/commodity.proto\"\xa8\x01\n\x1c\x43onstantDurationFutureDetail\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\r\n\x05price\x18\x02 \x01(\x01\x12*\n\x06\x65xpiry\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06weight\x18\x05 \x01(\x01\"b\n\x13RateQuoteConversion\x12\r\n\x05index\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xcc\x02\n\x16\x43onstantDurationFuture\x12\x14\n\x0c\x63omputed_cdf\x18\x01 \x01(\x01\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12<\n\x0c\x66ront_future\x18\x03 \x01(\x0b\x32&.kaikosdk.ConstantDurationFutureDetail\x12;\n\x0b\x62\x61\x63k_future\x18\x04 \x01(\x0b\x32&.kaikosdk.ConstantDurationFutureDetail\x12\x19\n\x11\x63onstant_duration\x18\x05 \x01(\x01\x12\x36\n\x06status\x18\x06 \x01(\x0e\x32&.kaikosdk.ConstantDurationFutureStatus\x12<\n\x15rate_quote_conversion\x18\x07 \x01(\x0b\x32\x1d.kaikosdk.RateQuoteConversion\"\x86\x01\n7StreamConstantDurationIndicesServiceResponseComposition\x12\x0c\n\x04\x62\x61se\x18\x01 \x01(\t\x12\r\n\x05quote\x18\x02 \x01(\t\x12.\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32 .kaikosdk.ConstantDurationFuture\"\xdb\x02\n.StreamConstantDurationIndicesServiceResponseV1\x12\x31\n\tcommodity\x18\x01 \x01(\x0e\x32\x1e.kaikosdk.StreamIndexCommodity\x12\x12\n\nindex_code\x18\x02 \x01(\t\x12V\n\x0b\x63omposition\x18\x03 \x01(\x0b\x32\x41.kaikosdk.StreamConstantDurationIndicesServiceResponseComposition\x12.\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08ts_event\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp*b\n\x1c\x43onstantDurationFutureStatus\x12\x0f\n\x0b\x43\x44\x46_UNKNOWN\x10\x00\x12\x0f\n\x0b\x43\x44\x46_SUCCESS\x10\x01\x12\r\n\tCDF_ERROR\x10\x02\x12\x11\n\rCDF_NO_FUTURE\x10\x03\x42\xc5\x01\n1com.kaiko.sdk.stream.constant_duration_indices_v1P\x01Zbgithub.com/kaikodata/kaiko-go-sdk/stream/constant_duration_indices_v1;constant_duration_indices_v1\xaa\x02)KaikoSdk.Stream.ConstantDurationIndicesV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.constant_duration_indices_v1.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n1com.kaiko.sdk.stream.constant_duration_indices_v1P\001Zbgithub.com/kaikodata/kaiko-go-sdk/stream/constant_duration_indices_v1;constant_duration_indices_v1\252\002)KaikoSdk.Stream.ConstantDurationIndicesV1'
  _globals['_CONSTANTDURATIONFUTURESTATUS']._serialized_start=1231
  _globals['_CONSTANTDURATIONFUTURESTATUS']._serialized_end=1329
  _globals['_CONSTANTDURATIONFUTUREDETAIL']._serialized_start=139
  _globals['_CONSTANTDURATIONFUTUREDETAIL']._serialized_end=307
  _globals['_RATEQUOTECONVERSION']._serialized_start=309
  _globals['_RATEQUOTECONVERSION']._serialized_end=407
  _globals['_CONSTANTDURATIONFUTURE']._serialized_start=410
  _globals['_CONSTANTDURATIONFUTURE']._serialized_end=742
  _globals['_STREAMCONSTANTDURATIONINDICESSERVICERESPONSECOMPOSITION']._serialized_start=745
  _globals['_STREAMCONSTANTDURATIONINDICESSERVICERESPONSECOMPOSITION']._serialized_end=879
  _globals['_STREAMCONSTANTDURATIONINDICESSERVICERESPONSEV1']._serialized_start=882
  _globals['_STREAMCONSTANTDURATIONINDICESSERVICERESPONSEV1']._serialized_end=1229
# @@protoc_insertion_point(module_scope)
