# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/orderbookl2_v1/order.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%sdk/stream/orderbookl2_v1/order.proto\x12\x08kaikosdk\"&\n\x05Order\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x01\x12\r\n\x05price\x18\x02 \x01(\x01\x42\x8d\x01\n#com.kaiko.sdk.stream.orderbookl2_v1P\x01ZFgithub.com/kaikodata/kaiko-go-sdk/stream/orderbookl2_v1;orderbookl2_v1\xaa\x02\x1bKaikoSdk.Stream.OrderBookL2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.orderbookl2_v1.order_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.kaiko.sdk.stream.orderbookl2_v1P\001ZFgithub.com/kaikodata/kaiko-go-sdk/stream/orderbookl2_v1;orderbookl2_v1\252\002\033KaikoSdk.Stream.OrderBookL2'
  _globals['_ORDER']._serialized_start=51
  _globals['_ORDER']._serialized_end=89
# @@protoc_insertion_point(module_scope)
